#!/bin/bash
#set -x
CPU_INFO="/etc/cpuinfo"

function set_boot () 
{
   if ( dd if=/dev/hda bs=512 count=1  2>/dev/null |grep GRUB >/dev/null 2>&1 ) ; then 
      BOOTLOADER="grub" 
   else
      BOOTLOADER="lilo" 
   fi
   BOOT_DISK="$(mount |grep boot|cut -b 1-8)"
   [ "$BOOT_DISK" = "" ] && BOOT_DISK="/dev/hda"
   if [ "$BOOTLOADER" = "grub" ] ; then
      grub-install $BOOT_DISK
   else
      lilo
   fi   
}

function set_lpj ()
{
   sed -i /etc/lilo.conf -e "s/^append\(.*\)[ ]*lpj=[0-9]*[ ]*\(.*\)/append\1 \2/"
   sed -i /boot/grub/grub.conf -e "s/^kernel \(.*\)[ ]*lpj=[0-9]*[ ]*\(.*\)/kernel \1 \2/"
   if [ "$1" = "set" ] ; then
      LPJ="$(dmesg|grep -m 1 "(lpj=[0-9]*" |sed -e "s/.*(lpj=\([0-9]*\).*/\1/")"
      logger -s "LPJ wird auf $LPJ gesetzt"
      sed -i /etc/lilo.conf -e "s/[ ]*$//g" -e "s/[ ]*\"$/\"/g" -e "s/^append\(.*\".*\)[ ]*\"/append\1 lpj=$LPJ\"/"
      sed -i /boot/grub/grub.conf -e "s/[ ]*$//g" -e "s/^kernel \(.*\)[ ]*$/kernel \1 lpj=$LPJ/"
   fi      
   set_boot
}

if [ "$(grep "^model name" /proc/cpuinfo)" != "$(cat $CPU_INFO 2>/dev/null)" ] ; then
   logger -s "CPU changed - removing LPJ settings"
   set_lpj
   grep "^model name" /proc/cpuinfo > $CPU_INFO
   [ -f $CPU_INFO ] && svdrpsend.pl MESG "CPU Wechsel erkannt - Reboot empfohlen"
   sh /_config/bin/powernow.sh > /dev/null 2>&1
else
   if ( ! grep "lpj=" /proc/cmdline > /dev/null 2>&1 ) ; then
      set_lpj set
   fi
fi
